# Copyright 2015-2016 Canonical Ltd.
#
# This file is part of the Telegraf Charm for Juju.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json

from charms.reactive import hook
from charms.reactive import RelationBase
from charms.reactive import scopes


class ExecProvides(RelationBase):
    scope = scopes.UNIT

    @hook('{provides:telegraf-exec}-relation-{joined,changed}')
    def changed(self):
        for conversation in self.conversations():
            conversation.set_state('{relation_name}.available')

    @hook('{provides:telegraf-exec}-relation-{departed,broken}')
    def broken(self):
        for conversation in self.conversations():
            conversation.remove_state('{relation_name}.available')

    def set_command(self, cmds, timeout, data_fmt):
        config = json.dumps([{
            'commands': cmds,
            'timeout': timeout,
            'data_format': data_fmt
        }])

        for conversation in self.conversations():
            conversation.set_remote(key="commands", value=config)
